==> haskell-skein-1.0.9.4-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-1WK0THXuob17gZECZv8qwn
key: skein-1.0.9.4-1WK0THXuob17gZECZv8qwn
license: BSD-3-Clause
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
abi: 01edf0684bcb0d66adb39a65043ebeb8
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-1WK0THXuob17gZECZv8qwn
includes:
    skein.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             crypto-api-0.13.3-9u8sDwmn8dvFreHHUkKG0l=c69dee8a034e34974872adcdcb0a4dd5
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skein-1.0.9.4-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-skein.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skein
version: 1.0.9.4
id: skein-1.0.9.4-HHNULLa284fJDkPZZYC8cT
key: skein-1.0.9.4-HHNULLa284fJDkPZZYC8cT
license: BSD-3-Clause
maintainer: Felipe Lessa <felipe.lessa@gmail.com>
author: Felipe Lessa <felipe.lessa@gmail.com>, Doug Whiting
homepage: https://github.com/meteficha/skein
synopsis: Skein, a family of cryptographic hash functions.  Includes Skein-MAC as well.
description:
    Skein (<http://www.skein-hash.info/>) is a family of fast
    secure cryptographic hash functions designed by Niels
    Ferguson, Stefan Lucks, Bruce Schneier, Doug Whiting, Mihir
    Bellare, Tadayoshi Kohno, Jon Callas and Jesse Walker.
    .
    This package uses bindings to the optimized C implementation
    of Skein.  We provide a high-level interface (see module
    "Crypto.Skein") to some of the Skein use cases.  We also
    provide a low-level interface (see module
    "Crypto.Skein.Internal") should you need to use Skein in a
    different way.
    .
    Currently we have support for Skein as cryptographic hash
    function as Skein as a message authentication code
    (Skein-MAC).  For examples of how to use this package, see
    "Crypto.Skein" module documentation.
    .
    This package includes Skein v1.3. Versions of this package
    before 1.0.0 implemented Skein v1.1.
category: Cryptography
abi: 15e4affd69ec203f14baa128e0fee683
exposed: True
exposed-modules:
    Crypto.Skein Crypto.Skein.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/skein-1.0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/skein-1.0.9.4
hs-libraries: HSskein-1.0.9.4-HHNULLa284fJDkPZZYC8cT
includes:
    skein.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             crypto-api-0.13.3-H6IfzwtYtsODXXfSTi5z5x=77fff9de6de15e8cfa3572530a17c761
haddock-interfaces: /usr/share/doc/haskell-skein/html/skein.haddock
haddock-html: /usr/share/doc/haskell-skein/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
